@@ -6,15 +6,15 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν επισημάνσεις που δεν έχουν αποθηκευτεί. Αφήνοντας τη σελίδα θα διαγραφούν όλες οι αλλαγές!",
     "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
     "File error" : "Σφάλμα αρχείου",
+    "Encryption Error" : "Σφάλμα κρυπτογράφησης",
     "Error" : "Σφάλμα",
+    "No notes found" : "Δεν βρέθηκαν σημειώσεις",
     "Delete note" : "Διαγραφή σημείωσης",
     "Favorite" : "Αγαπημένο",
-    "No notes found" : "Δεν βρέθηκαν σημειώσεις",
     "Settings" : "Ρυθμίσεις",
     "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
     "path to notes" : "διαδρομή στις σημειώσεις",
     "The note has unsaved changes." : "Η σημείωση έχει αλλαγές που δεν έχουν σωθεί",
-    "*" : "*",
     "Click here to try again" : "Κάντε κλίκ εδώ, για να δοκιμάσετε ξανά.",
     "Saving failed!" : "Απέτυχε η αποθήκευση!",
     "Note saved" : "Η σημείωση αποθηκεύτηκε."
