@@ -5,11 +5,17 @@ OC.L10N.register(
     "New note" : "Új jegyzet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
     "_%n word_::_%n words_" : ["%n szó","%n szó"],
+    "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
+    "File error" : "Fájlhiba",
+    "Encryption Error" : "Titkosítási hiba",
+    "Error" : "Hiba",
+    "No notes found" : "Nincsenek jegyzetek",
     "Delete note" : "Jegyzet törlése",
     "Favorite" : "Kedvenc",
-    "No notes found" : "Nincsenek jegyzetek",
+    "Settings" : "Beállítások",
+    "Folder to store your notes" : "A jegyzetek tárolási mappája",
+    "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
     "The note has unsaved changes." : "A jegyzet mentetlen módosításokat tartalmaz.",
-    "*" : "*",
     "Click here to try again" : "Kattints ide az ismételt kísérlethez",
     "Saving failed!" : "Mentés sikertelen!",
     "Note saved" : "Jegyzet mentve"
